OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Nedavni statusi",
    "No recent status changes" : "Nema nedavnih promjena statusa",
    "In a meeting" : "Na sastanku",
    "Commuting" : "Na putu",
    "Out sick" : "Na bolovanju",
    "Vacationing" : "Na odmoru",
    "Out of office" : "Izvan ureda",
    "Working remotely" : "Rad na daljinu",
    "In a call" : "U pozivu",
    "Be right back" : "Vraćam se odmah",
    "User status" : "Status korisnika",
    "Clear status after" : "Izbriši status nakon",
    "Emoji for your status message" : "Emoji za poruku statusa",
    "What is your status?" : "Koji je vaš status?",
    "Predefined statuses" : "Predefinirani statusi",
    "Previously set" : "Prethodno postavljeno",
    "Reset status" : "Poništi status",
    "Reset status to \"{icon} {message}\"" : "Poništi status na \"{icon} {message}\"",
    "Reset status to \"{message}\"" : "Poništi status na \"{message}\"",
    "Reset status to \"{icon}\"" : "Poništi status na \"{icon}\"",
    "There was an error saving the status" : "Došlo je do pogreške pri spremanju statusa",
    "There was an error clearing the status" : "Došlo je do pogreške pri brisanju statusa",
    "There was an error reverting the status" : "Došlo je do pogreške pri vraćanju statusa",
    "Online status" : "Status na mreži",
    "Status message" : "Poruka statusa",
    "Set absence period" : "Postavi razdoblje odsutnosti",
    "Set absence period and replacement" : "Postavi razdoblje odsutnosti i zamjenu",
    "Your status was set automatically" : "Vaš status je postavljen automatski",
    "Clear status message" : "Izbriši poruku statusa",
    "Set status message" : "Postavi poruku statusa",
    "Online" : "Na mreži",
    "Away" : "Odsutan",
    "Busy" : "Zauzeto",
    "Do not disturb" : "Ne ometaj",
    "Invisible" : "Nevidljiva",
    "Offline" : "Izvanmrežno",
    "Set status" : "Postavi status",
    "There was an error saving the new status" : "Došlo je do pogreške pri spremanju novog statusa",
    "Don't clear" : "Ne briši",
    "30 minutes" : "30 minuta",
    "1 hour" : "1 sat",
    "4 hours" : "4 sata",
    "Today" : "Danas",
    "This week" : "Ovaj tjedan",
    "Mute all notifications" : "Utišaj sve obavijesti",
    "Appear offline" : "Prikaži izvanmrežno"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
